@@ -79,7 +79,7 @@ ags_countable_get_notation_counter(AgsCountable *countable)
   g_return_val_if_fail(AGS_IS_COUNTABLE(countable), -1);
   countable_interface = AGS_COUNTABLE_GET_INTERFACE(countable);
   g_return_val_if_fail(countable_interface->get_notation_counter, -1);
-  countable_interface->get_notation_counter(countable);
+  return(countable_interface->get_notation_counter(countable));
 }
 
 /**
@@ -100,5 +100,5 @@ ags_countable_get_sequencer_counter(AgsCountable *countable)
   g_return_val_if_fail(AGS_IS_COUNTABLE(countable), -1);
   countable_interface = AGS_COUNTABLE_GET_INTERFACE(countable);
   g_return_val_if_fail(countable_interface->get_sequencer_counter, -1);
-  countable_interface->get_sequencer_counter(countable);
+  return(countable_interface->get_sequencer_counter(countable));
 }
